@@ -24,6 +24,7 @@
 
 #include <QList>
 #include <QTime>
+#include <QElapsedTimer>
 #include <QFlags>
 
 namespace KSysGuard
@@ -136,6 +137,9 @@ public:
     qlonglong vmURSS() const;
     void setVmURSS(qlonglong vmURSS);   ///< Physical memory used only by the process, and not counting the code for shared libraries. Set to -1 if unknown
 
+    qlonglong vmPSS() const;
+    void setVmPSS(qlonglong vmPSS); ///< Proportional set size, the amount of private physical memory used by the process + the amount of shared memory used divided over the number of processes using it.
+
     QString name() const;
     void setName(const QString &name);  ///< The name (e.g. "ksysguard", "konversation", "init")
 
@@ -196,11 +200,13 @@ public:
 
     qlonglong& vmURSSChange() const; // REF, make non-ref later!  ///< The change in vmURSS since last update, in KiB
 
+    qlonglong vmPSSChange() const; ///< The change in vmPSS since last update, in KiB.
+
     unsigned long& pixmapBytes() const; // REF, make non-ref later! ///< The number of bytes used for pixmaps/images and not counted by vmRSS or vmURSS
 
     bool& hasManagedGuiWindow() const; // REF, make non-ref later!
 
-    QTime timeKillWasSent() const; ///< This is usually a NULL time.  When trying to kill a process, this is the time that the kill signal was sent to the process.
+    QElapsedTimer timeKillWasSent() const; ///< This is usually a NULL time.  When trying to kill a process, this is the time that the kill signal was sent to the process.
 
     QString translatedStatus() const;  ///< Returns a translated string of the status. e.g. "Running" etc
 
@@ -212,13 +218,19 @@ public:
 
     QString schedulerAsString() const; ///< Returns a translated string of the scheduler class.  e.g. "FIFO", "Round Robin", "Batch"
 
+    QString cGroup() const;
+    void setCGroup(const QString &cGroup); ///< Linux Control Group (cgroup)
+
+    QString macContext() const;
+    void setMACContext(const QString &macContext); ///< Mandatory Access Control (SELinux or AppArmor) Context
+
     /** This is the number of 1/1000ths of a second since this
      *  particular process was last updated compared to when all the processes
      *  were updated. The purpose is to allow a more fine tracking of the time
      *  a process has been running for.
      *
      *  This is updated in processes.cpp and so shouldn't be touched by the
-     *  OS dependant classes.
+     *  OS dependent classes.
      */
     int elapsedTimeMilliSeconds() const;
     void setElapsedTimeMilliSeconds(int value);
@@ -243,7 +255,8 @@ public:
         Status = 0x1000,
         Login = 0x2000,
         IO = 0x4000,
-        NumThreads = 0x8000
+        NumThreads = 0x8000,
+        VmPSS = 0x10000,
     };
     Q_DECLARE_FLAGS(Changes, Change)
 
